==> git-cliff-2.9.1-crates.tar.xz: cargo_home/gentoo/next_version-0.2.24/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.24](https://github.com/release-plz/release-plz/compare/next_version-v0.2.23...next_version-v0.2.24) - 2025-03-17

### Other

- add more rust lints ([#2135](https://github.com/release-plz/release-plz/pull/2135))

## [0.2.23](https://github.com/release-plz/release-plz/compare/next_version-v0.2.22...next_version-v0.2.23) - 2025-03-01

### Other

- add new line to changelog header (#2098)

## [0.2.22](https://github.com/release-plz/release-plz/compare/next_version-v0.2.21...next_version-v0.2.22) - 2025-02-02

### Other

- *(next-version)* add test for scope with whitespace (#1997)
- use `git-conventional` library to parse commits (#2021)

## [0.2.21](https://github.com/release-plz/release-plz/compare/next_version-v0.2.20...next_version-v0.2.21) - 2024-12-07

### Other

- update Cargo.toml dependencies

## [0.2.20](https://github.com/release-plz/release-plz/compare/next_version-v0.2.19...next_version-v0.2.20) - 2024-11-21

### Other

- move `MarcoIeni/release-plz` to `release-plz/release-plz` ([#1850](https://github.com/release-plz/release-plz/pull/1850))

## [0.2.19](https://github.com/release-plz/release-plz/compare/next_version-v0.2.18...next_version-v0.2.19) - 2024-08-04

### Other
- update Cargo.toml dependencies

## [0.2.18](https://github.com/release-plz/release-plz/compare/next_version-v0.2.17...next_version-v0.2.18) - 2024-06-18

### Added
- support bumping version based on configurable custom pattern ([#1511](https://github.com/release-plz/release-plz/pull/1511))

## [0.2.17](https://github.com/release-plz/release-plz/compare/next_version-v0.2.16...next_version-v0.2.17) - 2024-05-27

### Other
- update Cargo.toml dependencies

## [0.2.16](https://github.com/release-plz/release-plz/compare/next_version-v0.2.15...next_version-v0.2.16) - 2024-05-05

### Other
- add `if_not_else` clippy lint ([#1438](https://github.com/release-plz/release-plz/pull/1438))

## [0.2.15](https://github.com/release-plz/release-plz/compare/next_version-v0.2.14...next_version-v0.2.15) - 2024-03-08

### Other
- use edition and license workspace ([#1329](https://github.com/release-plz/release-plz/pull/1329))

## [0.2.14](https://github.com/release-plz/release-plz/compare/next_version-v0.2.13...next_version-v0.2.14) - 2024-02-23

### Other
- update Cargo.toml dependencies

## [0.2.13](https://github.com/release-plz/release-plz/compare/next_version-v0.2.12...next_version-v0.2.13) - 2024-01-16

### Other
- update Cargo.toml dependencies

## [0.2.12](https://github.com/release-plz/release-plz/compare/next_version-v0.2.11...next_version-v0.2.12) - 2023-12-30

### Added
- *(next_version)* support configuration ([#1168](https://github.com/release-plz/release-plz/pull/1168))

## [0.2.11](https://github.com/release-plz/release-plz/compare/next_version-v0.2.10...next_version-v0.2.11) - 2023-12-13

### Other
- better document bump strategy ([#1132](https://github.com/release-plz/release-plz/pull/1132))

## [0.2.10](https://github.com/release-plz/release-plz/compare/next_version-v0.2.9...next_version-v0.2.10) - 2023-11-08

### Other
- *(next-version)* clarify patch increment ([#1065](https://github.com/release-plz/release-plz/pull/1065))

## [0.2.9](https://github.com/release-plz/release-plz/compare/next_version-v0.2.8...next_version-v0.2.9) - 2023-10-15

### Other
- update dependencies

## [0.2.8](https://github.com/release-plz/release-plz/compare/next_version-v0.2.7...next_version-v0.2.8) - 2023-09-30

### Other
- update dependencies

## [0.2.7](https://github.com/release-plz/release-plz/compare/next_version-v0.2.6...next_version-v0.2.7) - 2023-09-16

### Other
- add additional clippy lints ([#965](https://github.com/release-plz/release-plz/pull/965))

## [0.2.6](https://github.com/release-plz/release-plz/compare/next_version-v0.2.5...next_version-v0.2.6) - 2023-09-08

### Other
- *(ci)* check links ([#941](https://github.com/release-plz/release-plz/pull/941))

## [0.2.5](https://github.com/release-plz/release-plz/compare/next_version-v0.2.4...next_version-v0.2.5) - 2023-07-25

### Other
- update dependencies

## [0.2.4](https://github.com/release-plz/release-plz/compare/next_version-v0.2.3...next_version-v0.2.4) - 2023-04-16

### Other
- add test for breaking change in footer (#690)

## [0.2.3](https://github.com/release-plz/release-plz/compare/next_version-v0.2.2...next_version-v0.2.3) - 2023-03-13

### Other
- update dependencies

## [0.2.2](https://github.com/release-plz/release-plz/compare/next_version-v0.2.1...next_version-v0.2.2) - 2023-03-04

### Fixed
- always bump patch in 0.0.x versions (#578)

## [0.2.1](https://github.com/release-plz/release-plz/compare/next_version-v0.2.0...next_version-v0.2.1) - 2023-02-26

### Added
- add function to force breaking changes (#568)

## [0.2.0](https://github.com/release-plz/release-plz/compare/next_version-v0.1.10...next_version-v0.2.0) - 2023-01-11

### Added
- [**breaking**] don't remove build metadata (#433)
- [**breaking**] handle pre-releases (#425)

## [0.1.10](https://github.com/release-plz/release-plz/compare/next_version-v0.1.9...next_version-v0.1.10) - 2022-12-16

### Other
- Add functions to increment major, minor and patch version (#375)

## [0.1.9] - 2022-11-04

### Other
- use workspace dependencies (#333)

## [0.1.8] - 2022-10-24

### Other
- *(deps)* bump semver from 1.0.12 to 1.0.14 (#283)

## [0.1.7] - 2022-07-25

### Other
- inline the increment* functions to cut down dependencies (#220)

## [0.1.6] - 2022-07-16

### Other
- update to cargo edit 10 (#211)
- *(deps)* bump semver from 1.0.10 to 1.0.12 (#204)

## [0.1.5] - 2022-06-18

### Other
- *(deps)* bump semver from 1.0.9 to 1.0.10 (#180)

## [0.1.4] - 2022-05-19

### Other
- upgrade dependencies (#133)

## [0.1.3] - 2022-05-01

### Other
- remove default features from cargo-edit dependency (#101)

## [0.1.2] - 2022-04-27

### Other
- update dependencies (#91)

## [0.1.1] - 2022-03-27

### Fixed
- fix repository link

==> git-cliff-2.10.1-crates.tar.xz: cargo_home/gentoo/next_version-0.2.25/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.25](https://github.com/release-plz/release-plz/compare/next_version-v0.2.24...next_version-v0.2.25) - 2025-09-13

### Other

- update Cargo.toml dependencies

## [0.2.24](https://github.com/release-plz/release-plz/compare/next_version-v0.2.23...next_version-v0.2.24) - 2025-03-17

### Other

- add more rust lints ([#2135](https://github.com/release-plz/release-plz/pull/2135))

## [0.2.23](https://github.com/release-plz/release-plz/compare/next_version-v0.2.22...next_version-v0.2.23) - 2025-03-01

### Other

- add new line to changelog header (#2098)

## [0.2.22](https://github.com/release-plz/release-plz/compare/next_version-v0.2.21...next_version-v0.2.22) - 2025-02-02

### Other

- *(next-version)* add test for scope with whitespace (#1997)
- use `git-conventional` library to parse commits (#2021)

## [0.2.21](https://github.com/release-plz/release-plz/compare/next_version-v0.2.20...next_version-v0.2.21) - 2024-12-07

### Other

- update Cargo.toml dependencies

## [0.2.20](https://github.com/release-plz/release-plz/compare/next_version-v0.2.19...next_version-v0.2.20) - 2024-11-21

### Other

- move `MarcoIeni/release-plz` to `release-plz/release-plz` ([#1850](https://github.com/release-plz/release-plz/pull/1850))

## [0.2.19](https://github.com/release-plz/release-plz/compare/next_version-v0.2.18...next_version-v0.2.19) - 2024-08-04

### Other
- update Cargo.toml dependencies

## [0.2.18](https://github.com/release-plz/release-plz/compare/next_version-v0.2.17...next_version-v0.2.18) - 2024-06-18

### Added
- support bumping version based on configurable custom pattern ([#1511](https://github.com/release-plz/release-plz/pull/1511))

## [0.2.17](https://github.com/release-plz/release-plz/compare/next_version-v0.2.16...next_version-v0.2.17) - 2024-05-27

### Other
- update Cargo.toml dependencies

## [0.2.16](https://github.com/release-plz/release-plz/compare/next_version-v0.2.15...next_version-v0.2.16) - 2024-05-05

### Other
- add `if_not_else` clippy lint ([#1438](https://github.com/release-plz/release-plz/pull/1438))

## [0.2.15](https://github.com/release-plz/release-plz/compare/next_version-v0.2.14...next_version-v0.2.15) - 2024-03-08

### Other
- use edition and license workspace ([#1329](https://github.com/release-plz/release-plz/pull/1329))

## [0.2.14](https://github.com/release-plz/release-plz/compare/next_version-v0.2.13...next_version-v0.2.14) - 2024-02-23

### Other
- update Cargo.toml dependencies

## [0.2.13](https://github.com/release-plz/release-plz/compare/next_version-v0.2.12...next_version-v0.2.13) - 2024-01-16

### Other
- update Cargo.toml dependencies

## [0.2.12](https://github.com/release-plz/release-plz/compare/next_version-v0.2.11...next_version-v0.2.12) - 2023-12-30

### Added
- *(next_version)* support configuration ([#1168](https://github.com/release-plz/release-plz/pull/1168))

## [0.2.11](https://github.com/release-plz/release-plz/compare/next_version-v0.2.10...next_version-v0.2.11) - 2023-12-13

### Other
- better document bump strategy ([#1132](https://github.com/release-plz/release-plz/pull/1132))

## [0.2.10](https://github.com/release-plz/release-plz/compare/next_version-v0.2.9...next_version-v0.2.10) - 2023-11-08

### Other
- *(next-version)* clarify patch increment ([#1065](https://github.com/release-plz/release-plz/pull/1065))

## [0.2.9](https://github.com/release-plz/release-plz/compare/next_version-v0.2.8...next_version-v0.2.9) - 2023-10-15

### Other
- update dependencies

## [0.2.8](https://github.com/release-plz/release-plz/compare/next_version-v0.2.7...next_version-v0.2.8) - 2023-09-30

### Other
- update dependencies

## [0.2.7](https://github.com/release-plz/release-plz/compare/next_version-v0.2.6...next_version-v0.2.7) - 2023-09-16

### Other
- add additional clippy lints ([#965](https://github.com/release-plz/release-plz/pull/965))

## [0.2.6](https://github.com/release-plz/release-plz/compare/next_version-v0.2.5...next_version-v0.2.6) - 2023-09-08

### Other
- *(ci)* check links ([#941](https://github.com/release-plz/release-plz/pull/941))

## [0.2.5](https://github.com/release-plz/release-plz/compare/next_version-v0.2.4...next_version-v0.2.5) - 2023-07-25

### Other
- update dependencies

## [0.2.4](https://github.com/release-plz/release-plz/compare/next_version-v0.2.3...next_version-v0.2.4) - 2023-04-16

### Other
- add test for breaking change in footer (#690)

## [0.2.3](https://github.com/release-plz/release-plz/compare/next_version-v0.2.2...next_version-v0.2.3) - 2023-03-13

### Other
- update dependencies

## [0.2.2](https://github.com/release-plz/release-plz/compare/next_version-v0.2.1...next_version-v0.2.2) - 2023-03-04

### Fixed
- always bump patch in 0.0.x versions (#578)

## [0.2.1](https://github.com/release-plz/release-plz/compare/next_version-v0.2.0...next_version-v0.2.1) - 2023-02-26

### Added
- add function to force breaking changes (#568)

## [0.2.0](https://github.com/release-plz/release-plz/compare/next_version-v0.1.10...next_version-v0.2.0) - 2023-01-11

### Added
- [**breaking**] don't remove build metadata (#433)
- [**breaking**] handle pre-releases (#425)

## [0.1.10](https://github.com/release-plz/release-plz/compare/next_version-v0.1.9...next_version-v0.1.10) - 2022-12-16

### Other
- Add functions to increment major, minor and patch version (#375)

## [0.1.9] - 2022-11-04

### Other
- use workspace dependencies (#333)

## [0.1.8] - 2022-10-24

### Other
- *(deps)* bump semver from 1.0.12 to 1.0.14 (#283)

## [0.1.7] - 2022-07-25

### Other
- inline the increment* functions to cut down dependencies (#220)

## [0.1.6] - 2022-07-16

### Other
- update to cargo edit 10 (#211)
- *(deps)* bump semver from 1.0.10 to 1.0.12 (#204)

## [0.1.5] - 2022-06-18

### Other
- *(deps)* bump semver from 1.0.9 to 1.0.10 (#180)

## [0.1.4] - 2022-05-19

### Other
- upgrade dependencies (#133)

## [0.1.3] - 2022-05-01

### Other
- remove default features from cargo-edit dependency (#101)

## [0.1.2] - 2022-04-27

### Other
- update dependencies (#91)

## [0.1.1] - 2022-03-27

### Fixed
- fix repository link
